#!/bin/bash

# Author: Victor Correal (victor.correal@bsc.es)
# Date  : 1/05/2024

SOURCE_REPO=
GIT_BRANCH=
GIT_BRANCH_CMD=
SOURCE_TAR=
WORKDIR=
ENV_FILE=
FORCE=false
COMPILE_ONLY=false

# Force imports:
UTILS_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)"
source ${UTILS_DIR}/../../bash_utils/helpers.sh
source ${UTILS_DIR}/utils_args.sh
source ${UTILS_DIR}/utils_arch_files.sh

# 1. Check args && load env && workdir && move to workdir:
parse_args "$@"
check_required_args
print_options
source $ENV_FILE
check_dir && cd $WORKDIR
info "Running at $PWD"

# 2. Clone or locate sources if no compile!:
if [ -f "makenemo" ]; then
    info "Skipping cloning/locating sources"
elif [ $COMPILE_ONLY = true ]; then
    info "Compiling only mode selected"
else
    if [[ -z $SOURCE_REPO ]]; then
        git clone $SOURCE_REPO $GIT_BRANCH_CMD .
    elif [[ "$SOURCE_TAR" == *.tar.gz ]]; then
        tar -xzf $SOURCE_TAR
    elif [[ "$SOURCE_TAR" == *.tar ]]; then
        tar -xf $SOURCE_TAR
    else
        fatal "Unable to recognise format for $SOURCE_TAR"
    fi
fi

# 3. Check env variables:
check_nemo_env_vars
generate_nemo_env_file

# 4. Launch compilation
if declare -F nemo_build_pre_compile > /dev/null; then
    info "Found nemo_build_pre_compile method!"
    nemo_build_pre_compile ".nemo-make-hack"
fi

info "Starting compilation now..."

NEMO_CFG=${CFG_NAME}
NEMO_MAKE_PARALLEL_LEVEL=16
NEMO_SUBCOMPONENTS="OCE ICE"
NEMO_KEYS_TO_DELETE="key_top"
NEMO_KEYS_TO_ADD="key_asminc key_netcdf4 key_sms key_xios2 key_nosignedzero"

./makenemo  -j $NEMO_MAKE_PARALLEL_LEVEL -r ORCA2_ICE_PISCES \
            -n "$NEMO_CFG" -d "$NEMO_SUBCOMPONENTS" \
            -m $ARCH_NAME add_key "$NEMO_KEYS_TO_ADD" \
            del_key "$NEMO_KEYS_TO_DELETE" || fatal "makenemo failed."


